Crate kcr_atlasmap_io

Crate kcr_atlasmap_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the atlasmap.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

atlasmap.io/v1alpha1

  • AtlasMap

Modules

v1alpha1